# hydra
A cloud-agnostic Machine Learning Platform that will enable Data Scientists to run multiple experiments, perform hyper parameter optimization, evaluate results and serve models (batch/realtime) while still maintaining a uniform development UX across cloud environments 

## Installation Guide

hydra is not hosted on a python package server yet. So for now we install it by cloning the repo

```
git clone git@github.com:georgianpartners/hydra.git

cd hydra
pip3 install -e .
```

Check the current hydra version using
```
hydra --version
```
